from .exceptions import (
    SlovoException,
    SameLangsError,
    DiffLangsError,
    ImmutableClassError,
)

from .version import __version__
from .terms import Gender, Term
from .word import Word
